@@ -63,6 +63,9 @@
 
 namespace clan
 {
+	HMODULE Win32Window::moduleUser32 = 0;
+	Win32Window::FuncGetDpiForWindow* Win32Window::ptrGetDpiForWindow = nullptr;
+
 	Win32Window::Win32Window()
 	: hwnd(0), destroy_hwnd(true), current_cursor(0), large_icon(0), small_icon(0), cursor_set(false), cursor_hidden(false), site(0),
 	  minimum_size(0,0), maximum_size(0xffff, 0xffff), allow_dropshadow(false),
@@ -73,6 +76,16 @@ namespace clan
 		ReleaseDC(0, dc);
 		set_pixel_ratio(ppi / 96.0f);
 
+		if (!moduleUser32)
+		{
+			moduleUser32 = LoadLibrary(L"user32.dll");
+		}
+		if (moduleUser32)
+		{
+			// This is available on Windows 10 and beyond
+			ptrGetDpiForWindow = (FuncGetDpiForWindow*)GetProcAddress(moduleUser32, "GetDpiForWindow");
+		}
+
 		keyboard = InputDevice(new InputDeviceProvider_Win32Keyboard(this));
 		mouse = InputDevice(new InputDeviceProvider_Win32Mouse(this));
 
@@ -640,6 +653,21 @@ namespace clan
 			else if ((wparam == ICON_SMALL || wparam == ICON_SMALL2) && small_icon)
 				return reinterpret_cast<LRESULT>(small_icon);
 			break;
+
+		case WM_DPICHANGED:
+			set_pixel_ratio(LOWORD(wparam) / 96.0f);
+			if (lparam)
+			{
+				RECT* const prcNewWindow = (RECT*)lparam;
+				SetWindowPos(wnd,
+					NULL,
+					prcNewWindow->left,
+					prcNewWindow->top,
+					prcNewWindow->right - prcNewWindow->left,
+					prcNewWindow->bottom - prcNewWindow->top,
+					SWP_NOZORDER | SWP_NOACTIVATE);
+			}
+			break;
 		}
 
 		// Do default window processing if our message handler didn't handle it:
@@ -727,6 +755,12 @@ namespace clan
 			}
 		}
 
+		if (ptrGetDpiForWindow)	// Supported for windows 10 and above
+		{
+			int ppi = ptrGetDpiForWindow(hwnd);
+			set_pixel_ratio(ppi / 96.0f);
+		}
+
 		connect_window_input(window_desc);
 	}
 
@@ -1488,7 +1522,7 @@ namespace clan
 	void Win32Window::register_clipboard_formats()
 	{
 	//	WCHAR *png_format_str = L"image/png";
-		WCHAR *png_format_str = L"PNG";
+		const WCHAR *png_format_str = L"PNG";
 		png_clipboard_format = RegisterClipboardFormat(png_format_str);
 	}
 
@@ -1733,7 +1767,18 @@ namespace clan
 			int primary_screen = 0;
 			ScreenInfo screen_info;
 			std::vector<Rectf> screen_rects = screen_info.get_screen_geometries(primary_screen);
-			Rectf R = screen_rects[desc.get_fullscreen_monitor()];
+			Rectf R;
+			if (desc.get_fullscreen_monitor() < screen_rects.size())
+			{
+				R = screen_rects[desc.get_fullscreen_monitor()];
+			}else if (screen_rects.empty())
+			{
+				R.right = GetSystemMetrics(SM_CXSCREEN);
+				R.bottom = GetSystemMetrics(SM_CYSCREEN);
+			}else
+			{
+				R = screen_rects[0];
+			}
 
 			clientSize = false;
 			x = (int)std::round(R.left * pixel_ratio);
