@@ -1,6 +1,6 @@
 /*
 **  ClanLib SDK
-**  Copyright (c) 1997-2005 The ClanLib Team
+**  Copyright (c) 1997-2020 The ClanLib Team
 **
 **  This software is provided 'as-is', without any express or implied
 **  warranty.  In no event will the authors be held liable for any damages
@@ -24,51 +24,22 @@
 **  File Author(s):
 **
 **    Magnus Norddahl
-**    (if your name is missing here, please add it)
 */
 
-#ifndef header_precomp
-#define header_precomp
-
-#if _MSC_VER > 1000
 #pragma once
-#endif
-
 
 #ifdef WIN32
 #ifdef _MSC_VER
 # pragma warning (disable:4786)
 #endif
 #include <windows.h>
-#include <process.h>
-#include <dsound.h>
-#include <stdlib.h>
-#include <math.h>
-#include <conio.h>
 #endif
 
-#include "API/signals.h"
-#include "API/Core/System/error.h"
-
-#ifdef __BORLANDC__
-#define BAD_MATH
-#endif
-
-#ifdef BAD_MATH
-#define sqrtf sqrt
-#define acosf acos
-#define sinf sin
-#define cosf cos
-#endif
+#include "API/Core/System/exception.h"
 
 #if defined(_DEBUG) && !defined(DEBUG)
 #define DEBUG
 #endif
 
-#ifdef WIN32
-#define BREAKPOINT
-#else
-#define BREAKPOINT asm("int $03");
-#endif
+#include <cstring>
 
-#endif
