@@ -28,6 +28,7 @@
 
 #pragma once
 
+#include <memory>
 #include <vector>
 #include <mutex>
 
@@ -42,7 +43,7 @@ namespace clan
 		SoundBuffer_Impl();
 		virtual ~SoundBuffer_Impl();
 
-		SoundProvider *provider;
+		std::unique_ptr<SoundProvider> provider;
 		float volume;
 		float pan;
 		std::vector<SoundFilter> filters;
